@@ -156,7 +156,7 @@ def viirs(scans_nb, scan_indices=slice(0, None),
     """
 
     entire_width = np.arange(chn_pixels)
-    scan_points = entire_width[scan_indices.astype('int')]
+    scan_points = entire_width[scan_indices].astype('int')
     scan_pixels = len(scan_points)
 
     # Initial angle 55.84 deg replaced with 56.28 deg found in
