@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2014 Martin Raspaud
+# Copyright (c) 2012-2014, 2022 Pytroll Community
 
 # Author(s):
 
@@ -410,16 +410,3 @@ class TestRegressions(unittest.TestCase):
                       line2="2 37849  98.7092 229.3263 0000715  98.5313 290.6262 14.19554485413345")
         orb.get_next_passes(parser.parse("2019-10-21 16:00:00"), 12, 123.29736, -13.93763, 0)
         warnings.filterwarnings('default')
-
-
-def suite():
-    """The suite for test_orbital
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(Test))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestGetObserverLook))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestGetObserverLookNadir))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestRegressions))
-
-    return mysuite
