@@ -37,16 +37,18 @@ import sqlite3
 from xml.etree import ElementTree as ET
 from itertools import zip_longest
 
+TLE_GROUPS = ('active',
+              'weather',
+              'resource',
+              'cubesat',
+              'stations',
+              'sarsat',
+              'noaa',
+              'amateur',
+              'engineering')
 
-TLE_URLS = ('https://celestrak.org/NORAD/elements/active.txt',
-            'https://celestrak.org/NORAD/elements/weather.txt',
-            'https://celestrak.org/NORAD/elements/resource.txt',
-            'https://celestrak.org/NORAD/elements/cubesat.txt',
-            'https://celestrak.org/NORAD/elements/stations.txt',
-            'https://celestrak.org/NORAD/elements/sarsat.txt',
-            'https://celestrak.org/NORAD/elements/noaa.txt',
-            'https://celestrak.org/NORAD/elements/amateur.txt',
-            'https://celestrak.org/NORAD/elements/engineering.txt')
+TLE_URLS = [f'https://celestrak.org/NORAD/elements/gp.php?GROUP={group}&FORMAT=tle'
+            for group in TLE_GROUPS]
 
 
 LOGGER = logging.getLogger(__name__)
@@ -323,7 +325,7 @@ def _get_uris_and_open_func(tle_file=None):
     elif local_tle_path:
         # TODO: get the TLE file closest in time to the actual satellite
         # overpass, NOT the latest!
-        list_of_tle_files = glob.glob(os.path.join(local_tle_path, '*'))
+        list_of_tle_files = glob.glob(local_tle_path)
         uris = (max(list_of_tle_files, key=os.path.getctime), )
         LOGGER.debug("Reading TLE from %s", uris[0])
         open_func = _open
